# NanoDB [![Build Status](https://travis-ci.org/pmdartus/NanoCube.svg?branch=master)](https://travis-ci.org/pmdartus/NanoCube) [![Coverage Status](https://coveralls.io/repos/pmdartus/NanoCube/badge.png?branch=master)](https://coveralls.io/r/pmdartus/NanoCube?branch=master)

In-memory data structure for spatiotemporal data cubes. Project based on research made 
by [Information Visualization department](http://www.research.att.com/infovis) at AT&T.

## Installation

```
pip install nanodb
```
The package contains following command tools: `nanodb`and `nanodb_server`.

**Warning:** Currently support python 2.7 only.